==> FuncsForSPO-5.1.5.tar.gz: FuncsForSPO-5.1.5/FuncsForSPO/fpdf/fanalyser/base.py <==
from selenium.webdriver import Chrome
from selenium import webdriver
from selenium.webdriver.common.keys import Keys
from selenium.webdriver.chrome.options import Options as ChromeOptions
from selenium.webdriver.chrome.service import Service
from selenium.webdriver.common.by import By
from selenium.webdriver.support.wait import WebDriverWait
from selenium.common.exceptions import *
from webdriver_manager.chrome import ChromeDriverManager
from FuncsForSPO.fpython.functions_for_py import *
from FuncsForSPO.fselenium.functions_selenium import *
from FuncsForSPO.fwinotify.fwinotify import *
from FuncsForSPO.fregex.functions_re import *
from FuncsForSPO.fpdf.focr.orc import *
from FuncsForSPO.fpysimplegui.functions_for_sg import *
import pandas as pd
import re
import json
import os

class BotMain:    
    def __init__(self, headless) -> None:
        # --- CHROME OPTIONS --- #
        self._options = ChromeOptions()
        
        if headless == True:
            self._options.add_argument('--headless')
            self._options.add_experimental_option("excludeSwitches", ["enable-logging", "enable-automation"])
            self._options.add_experimental_option('useAutomationExtension', False)
            self.user_agent = cria_user_agent()
            # faz_log(self.user_agent)
            # self._options.add_argument(f"--user-agent={self.user_agent}")
            # self._options.add_argument("--disable-web-security")
            # self._options.add_argument("--allow-running-insecure-content")
            # self._options.add_argument("--start-maximized")
            # self._options.add_argument("--no-sandbox")
            # self._options.add_argument('--disable-gpu')
            # self._options.add_argument('--disable-software-rasterizer')
            self._options.add_argument('--incognito')
            self._options.add_argument("--window-size=1920,1080")
        else:
            self._options.add_experimental_option("excludeSwitches", ["enable-logging", "enable-automation"])
            self._options.add_experimental_option('useAutomationExtension', False)
            self.user_agent = cria_user_agent()
            # faz_log(self.user_agent)
            # self._options.add_argument(f"--user-agent=Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36")
            # self._options.add_argument("--disable-web-security")
            # self._options.add_argument("--allow-running-insecure-content")
            # self._options.add_argument("--start-maximized")
            # self._options.add_argument("--no-sandbox")
            # self._options.add_argument('--disable-gpu')
            # self._options.add_argument('--disable-software-rasterizer')
            # self._options.add_argument('--incognito')
            self._options.add_argument("--window-size=1920,1080")
            self._options.add_argument('--kiosk-printing')

        
        self.__service = Service(ChromeDriverManager().install())
        
        # create DRIVER
        self.DRIVER = Chrome(service=self.__service, options=self._options)

        self.WDW3 = WebDriverWait(self.DRIVER, timeout=3)
        self.WDW5 = WebDriverWait(self.DRIVER, timeout=5)
        self.WDW7 = WebDriverWait(self.DRIVER, timeout=7)
        self.WDW10 = WebDriverWait(self.DRIVER, timeout=10)
        self.WDW30 = WebDriverWait(self.DRIVER, timeout=30)
        self.WDW130 = WebDriverWait(self.DRIVER, timeout=130)
        self.WDW330 = WebDriverWait(self.DRIVER, timeout=330)
        self.WDW = self.WDW7

        self.DRIVER.maximize_window()
        return self.DRIVER

==> FuncsForSPO-6.2.6.tar.gz: FuncsForSPO-6.2.6/FuncsForSPO/fpdf/fanalyser/base.py <==
from selenium.webdriver import Chrome
from selenium import webdriver
from selenium.webdriver.common.keys import Keys
from selenium.webdriver.chrome.options import Options as ChromeOptions
from selenium.webdriver.chrome.service import Service
from selenium.webdriver.common.by import By
from selenium.webdriver.support.wait import WebDriverWait
from selenium.common.exceptions import *
from webdriver_manager.chrome import ChromeDriverManager
from FuncsForSPO.fpython.functions_for_py import *
from FuncsForSPO.fselenium.functions_selenium import *
from FuncsForSPO.fwinotify.fwinotify import *
from FuncsForSPO.fregex.functions_re import *
from FuncsForSPO.fpdf.focr.orc import *
from FuncsForSPO.fpysimplegui.functions_for_sg import *
import pandas as pd
import re
import json
import os

class BotMain:    
    def __init__(self, headless) -> None:
        # --- CHROME OPTIONS --- #
        self._options = ChromeOptions()
        
        if headless == True:
            self._options.add_argument('--headless')
            self._options.add_experimental_option("excludeSwitches", ["enable-logging", "enable-automation"])
            self._options.add_experimental_option('useAutomationExtension', False)
            self.user_agent = cria_user_agent()
            # faz_log(self.user_agent)
            # self._options.add_argument(f"--user-agent={self.user_agent}")
            self._options.add_argument("--disable-web-security")
            self._options.add_argument("--allow-running-insecure-content")
            self._options.add_argument("--start-maximized")
            self._options.add_argument("--no-sandbox")
            self._options.add_argument('--disable-gpu')
            self._options.add_argument('--disable-software-rasterizer')
            self._options.add_argument('--incognito')
            self._options.add_argument("--window-size=1920,1080")
        else:
            self._options.add_experimental_option("excludeSwitches", ["enable-logging", "enable-automation"])
            self._options.add_experimental_option('useAutomationExtension', False)
            self.user_agent = cria_user_agent()
            # faz_log(self.user_agent)
            # self._options.add_argument(f"--user-agent={self.user_agent}")
            self._options.add_argument("--disable-web-security")
            self._options.add_argument("--allow-running-insecure-content")
            self._options.add_argument("--start-maximized")
            self._options.add_argument("--no-sandbox")
            self._options.add_argument('--disable-gpu')
            self._options.add_argument('--disable-software-rasterizer')
            self._options.add_argument('--incognito')
            self._options.add_argument("--window-size=1920,1080")
            self._options.add_argument('--kiosk-printing')

        
        self.__service = Service(ChromeDriverManager().install())
        
        # create DRIVER
        self.DRIVER = Chrome(service=self.__service, options=self._options)

        self.WDW3 = WebDriverWait(self.DRIVER, timeout=3)
        self.WDW5 = WebDriverWait(self.DRIVER, timeout=5)
        self.WDW7 = WebDriverWait(self.DRIVER, timeout=7)
        self.WDW10 = WebDriverWait(self.DRIVER, timeout=10)
        self.WDW30 = WebDriverWait(self.DRIVER, timeout=30)
        self.WDW130 = WebDriverWait(self.DRIVER, timeout=130)
        self.WDW330 = WebDriverWait(self.DRIVER, timeout=330)
        self.WDW = self.WDW7

        self.DRIVER.maximize_window()
        return self.DRIVER
